==> bookmarkbridge_0.72.orig.tar.gz: bookmarkbridge-0.72/bookmarkbridge/dlgmain.h <==
/***************************************************************************
                          dlgmain.h  -  description
                             -------------------
    begin                : Sat Dec 28 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kenschenke at yahoo dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   In addition, as a special exception, Ken Schenke gives permission to  *
 *   link the code of this program with the Qt non-commercial edition (or  *
 *   with modified versions of the Qt non-commercial edition that use the  *
 *   same license as the Qt non-commercial edition, and distribute linked  *
 *   combinations including the two.  You must obey the GNU General Public *
 *   License in all respects for all of the code used other than the Qt    *
 *   Non-Commercial edition.  If you modify this file, you may extend this *
 *   exception to your version of the file, but you are not obligated to   *
 *   do so.  If you do not wish to do so, delete this exception statement  *
 *   from your version.                                                    *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGMAIN_H
#define DLGMAIN_H

#include "dlgmainbase.h"
#include "bridgecfg.h"

/***************************************************************************
 *                                                                         *
 *   Forward declarations.                                                 *
 *                                                                         *
 ***************************************************************************/

class DlgHelp;

/***************************************************************************
 *                                                                         *
 *   The DlgMain class represents the main dialog box that serves as       *
 *   BookmarkBridge's primary interface.                                   *
 *                                                                         *
 ***************************************************************************/

class DlgMain : public DlgMainBase
{
	Q_OBJECT
public:
	DlgMain( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags f = 0 );
	virtual ~DlgMain();

	virtual void buttonAboutClicked(void);
	virtual void buttonAddDestinationClicked(void);
	virtual void buttonAddSourceClicked(void);
	virtual void buttonDeleteDestinationClicked(void);
	virtual void buttonDeleteSourceClicked(void);
	virtual void buttonHelpClicked(void);
	virtual void buttonMergeClicked(void);
	virtual void buttonSettingsClicked(void);
	virtual void buttonViewBookmarksClicked(void);
	virtual void listDestinationsSelectionChanged(void);
	virtual void listSourcesSelectionChanged(void);
	
private:
	BridgeCfg	m_cfg;
	DlgHelp *	m_dlgHelp;

	void		refreshButtons(void);
	void		refreshLists(void);
};

#endif	// end of DLGMAIN_H

==> bookmarkbridge_0.76.orig.tar.gz: bookmarkbridge-0.76/bookmarkbridge/dlgmain.h <==
/***************************************************************************
                          dlgmain.h  -  description
                             -------------------
    begin                : Sat Dec 28 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
 *   02110-1301, USA                                                       *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGMAIN_H
#define DLGMAIN_H

#include <QDialog>
#include "ui_dlgmain.h"
#include "bridgecfg.h"

/***************************************************************************
 *                                                                         *
 *   Forward declarations.                                                 *
 *                                                                         *
 ***************************************************************************/

class DlgHelp;

/***************************************************************************
 *                                                                         *
 *   The DlgMain class represents the main dialog box that serves as       *
 *   BookmarkBridge's primary interface.                                   *
 *                                                                         *
 ***************************************************************************/

class DlgMain : public QDialog, public Ui::DlgMain
{
	Q_OBJECT;

public:
	DlgMain( QWidget* parent = 0 );
	virtual ~DlgMain();

public slots:
	void on_buttonAbout_clicked(void);
	void on_buttonDestAdd_clicked(void); 
	void on_buttonHelp_clicked(void);
	void on_buttonSettings_clicked(void);
	void on_buttonSourceAdd_clicked(void); 
	void on_buttonView_clicked(void);
	void on_listSources_currentRowChanged(void);
	void on_listDestinations_currentRowChanged(void);
	void on_buttonSourceDelete_clicked(void);
	void on_buttonDestDelete_clicked(void);
	void on_buttonMerge_clicked(void);

private:
	BridgeCfg	m_cfg;
	DlgHelp *	m_dlgHelp;

	void		refreshButtons(void);
	void		refreshLists(void);
};

#endif	// end of DLGMAIN_H
